import {
  AlipayCircleOutlined,
  LockOutlined,
  MobileOutlined,
  TaobaoCircleOutlined,
  UserOutlined,
  WeiboCircleOutlined,
} from "@ant-design/icons";
import { Alert, message, Tabs, Row, Col } from "antd";
import React, { useState } from "react";
import {
  ProFormCaptcha,
  ProFormCheckbox,
  ProFormText,
  LoginForm,
} from "@ant-design/pro-form";
import { Link, history, FormattedMessage, useModel } from "umi";
import { fakeAccountLogin } from "@/services/login";
import styles from "./index.less";
import AES from "crypto-js/aes";
import ECB from "crypto-js/mode-ecb";
import Pkcs7 from "crypto-js/pad-pkcs7";
import Utf8 from "crypto-js/enc-utf8";
import moment from "moment";

const LoginMessage = ({ content }) => (
  <Alert
    style={{
      marginBottom: 24,
    }}
    message={content}
    type="error"
    showIcon
  />
);

const { TabPane } = Tabs;

let col = { xs: 0, sm: 0, md: 7, lg: 6, xl: 6, xxl: 6 },
  cols = { xs: 24, sm: 24, md: 17, lg: 18, xl: 18, xxl: 18 };

const Login = () => {
  const { initialState, setInitialState } = useModel("@@initialState");
  const [tabkey, settabkey] = useState();
  const fetchUserInfo = async () => {
    const userInfo = await initialState?.fetchUserInfo(),
      menuData = await initialState?.getmenuData();

    if (userInfo) {
      await setInitialState((s) => {
        return { ...s, currentUser: userInfo?.data, newMenu: menuData };
      });
    }
  };

  const handleSubmit = async (values) => {
    let timestamp = moment().valueOf().toString() + "acb";
    let newtimestamp = AES.encrypt(timestamp, Utf8.parse("NANGAODEAESKEY--"), {
      mode: ECB,
      padding: Pkcs7,
    }).toString();

    let password = AES.encrypt(values.password, Utf8.parse(timestamp), {
      mode: ECB,
      padding: Pkcs7,
    }).toString();

    const postdata = {
      accountName: values.userName,
      password: password,
      encryptKey: newtimestamp,
    };
    try {
      // 登录
      const res = await fakeAccountLogin({ ...postdata });
      if (res.code === "0000") {
        let token = res?.data?.token;
        localStorage.setItem("TOKEN_MES", token);
        await fetchUserInfo();
        message.success("🎉 🎉 🎉  登录成功！");
        /** 此方法会跳转到 redirect 参数所在的位置 */
        if (!history) return;
        const { query } = history.location;
        const { redirect } = query;
        history.push(redirect || "/");
        return;
      }
    } catch (error) {
      message.error(res.msg);
    }
  };
  return (
    <Row className={styles.container}>
      <Col {...col}>
        <div
          className="img"
          style={{
            backgroundImage: `url(${require("@/assets/loginbg.jpg")})`,
            position: "relative",
          }}
        >
          <div className="cover">
            <img alt="logo" src={require("@/assets/logo_white.png")} />
          </div>
        </div>
      </Col>
      <Col {...cols}>
        <div className={styles.content} id="content">
          <LoginForm
            title={<span style={{ color: "#fff" }}>WMS</span>}
            subTitle={
              <span style={{ color: "rgba(255,255,255,0.6)" }}>
                智慧仓储管理系统
              </span>
            }
            initialValues={{
              autoLogin: true,
            }}
            onFinish={async (values) => {
              await handleSubmit(values);
            }}
          >
            <Tabs
              activeKey={tabkey}
              onChange={settabkey}
              tabBarStyle={{ color: "#fff" }}
            >
              <TabPane tab="登录" key="1">
                {tabkey == "1" && (
                  <>
                    <ProFormText
                      name="userName"
                      fieldProps={{
                        size: "large",
                        prefix: <UserOutlined className={styles.prefixIcon} />,
                      }}
                      placeholder="用户名"
                      rules={[
                        {
                          required: true,
                          message: "请输入用户名!",
                        },
                      ]}
                    />
                    <ProFormText.Password
                      name="password"
                      fieldProps={{
                        size: "large",
                        prefix: <LockOutlined className={styles.prefixIcon} />,
                      }}
                      placeholder="密码"
                      rules={[
                        {
                          required: true,
                          message: "请输入密码！",
                        },
                      ]}
                    />
                  </>
                )}
              </TabPane>
              <TabPane tab="注册" key="2"></TabPane>
            </Tabs>

            <div
              style={{
                marginBottom: 12,
                height: 0,
              }}
            >
              {/* <Link to="/user/logon"
                style={{
                  float: 'right',
                  textShadow: "0 0 4px #999"
                }}
              >
                <FormattedMessage id="pages.login.registerAccount" defaultMessage="" />
              </Link> */}
            </div>
          </LoginForm>
        </div>
      </Col>
    </Row>
  );
};

export default Login;
